@@ -60,8 +60,9 @@ def set_rocketcea_data_dir( rddir, do_print=True ):
         print( 'Setting ROCKETCEA_DATA_DIR =', ROCKETCEA_DATA_DIR )
     # try to solve spaces in Windows Path names by making 8.3, short path names.
     if ROCKETCEA_DATA_DIR.find(' ') >= 0:
-        print('WARNING: ROCKETCEA_DATA_DIR contains space characters:')
-        print('   ',ROCKETCEA_DATA_DIR)
+        if do_print:
+            print('WARNING: ROCKETCEA_DATA_DIR contains space characters:')
+            print('   ',ROCKETCEA_DATA_DIR)
         ROCKETCEA_DATA_DIR = get_usable_path( ROCKETCEA_DATA_DIR )
         
 set_rocketcea_data_dir( ROCKETCEA_DATA_DIR, do_print=False )
@@ -827,6 +828,11 @@ class CEA_Obj(object):
         Cstar = float(py_cea.rockt.cstr)
         Tcomb = py_cea.prtout.ttt[ self.i_chm ] * 1.8  # convert from Kelvin to Rankine
         mw,gam = py_cea.prtout.wm[ self.i_exit ], py_cea.prtout.gammas[ self.i_exit ]
+        
+        try:
+            mw = 1.0 / py_cea.prtout.totn[ self.i_exit ] 
+        except:
+            pass # just use above mw if 1/totn fails
 
         return IspVac, Cstar, Tcomb, mw, gam
 
@@ -848,6 +854,11 @@ class CEA_Obj(object):
         Cstar = float(py_cea.rockt.cstr)
         Tcomb = py_cea.prtout.ttt[ self.i_chm ] * 1.8  # convert from Kelvin to Rankine
         mw,gam = py_cea.prtout.wm[ self.i_chm ], py_cea.prtout.gammas[ self.i_chm ]
+        
+        try:
+            mw = 1.0 / py_cea.prtout.totn[ self.i_chm ] 
+        except:
+            pass # just use above mw if 1/totn fails
 
         return IspVac, Cstar, Tcomb, mw, gam
 
@@ -868,6 +879,11 @@ class CEA_Obj(object):
         Cstar = float(py_cea.rockt.cstr)
         Tcomb = py_cea.prtout.ttt[ self.i_chm ] * 1.8  # convert from Kelvin to Rankine
         mw,gam = py_cea.prtout.wm[ self.i_thrt ], py_cea.prtout.gammas[ self.i_thrt ]
+        
+        try:
+            mw = 1.0 / py_cea.prtout.totn[ self.i_thrt ] 
+        except:
+            pass # just use above mw if 1/totn fails
 
         return IspVac, Cstar, Tcomb, mw, gam
 
@@ -1341,6 +1357,12 @@ class CEA_Obj(object):
         self.setupCards( Pc=Pc, MR=MR, eps=eps)
 
         mw,gam = py_cea.prtout.wm[ self.i_chm ], py_cea.prtout.gammas[ self.i_chm ]
+        
+        try:
+            mw = 1.0 / py_cea.prtout.totn[ self.i_chm ] 
+        except:
+            pass # just use above mw if 1/totn fails
+        
         return mw,gam
 
     def get_Throat_MolWt_gamma(self, Pc=100.0, MR=1.0, eps=40.0, frozen=0):
@@ -1356,6 +1378,12 @@ class CEA_Obj(object):
         self.setupCards( Pc=Pc, MR=MR, eps=eps, frozen=frozen)
 
         mw,gam = py_cea.prtout.wm[ self.i_thrt ], py_cea.prtout.gammas[ self.i_thrt ]
+        
+        try:
+            mw = 1.0 / py_cea.prtout.totn[ self.i_thrt ] 
+        except:
+            pass # just use above mw if 1/totn fails
+        
         return mw,gam
 
     def get_exit_MolWt_gamma(self, Pc=100.0, MR=1.0, eps=40.0, frozen=0, frozenAtThroat=0):
@@ -1372,6 +1400,12 @@ class CEA_Obj(object):
         self.setupCards( Pc=Pc, MR=MR, eps=eps, frozen=frozen, frozenAtThroat=frozenAtThroat)
 
         mw,gam = py_cea.prtout.wm[ self.i_exit ], py_cea.prtout.gammas[ self.i_exit ]
+        
+        try:
+            mw = 1.0 / py_cea.prtout.totn[ self.i_exit ] 
+        except:
+            pass # just use above mw if 1/totn fails
+        
         return mw,gam
 
 
@@ -1433,6 +1467,12 @@ class CEA_Obj(object):
 
         IspVac = py_cea.rockt.vaci[ self.i_exit ]
         mw,gam = py_cea.prtout.wm[ self.i_thrt ], py_cea.prtout.gammas[ self.i_thrt ] # throat gamma
+        
+        try:
+            mw = 1.0 / py_cea.prtout.totn[ self.i_thrt ] 
+        except:
+            pass # just use above mw if 1/totn fails
+        
         #PcOvPe = py_cea.rockt.app[ self.i_exit ]
         Pexit = py_cea.prtout.ppp[ self.i_exit ]*14.7/1.01325
         #print( "=============== Pexit ", Pexit, py_cea.prtout.ppp[ self.i_exit ]/1.01325, py_cea.prtout.ppp[ self.i_exit ] )
@@ -1604,7 +1644,7 @@ def print_py_cea_vars():
             print()
 
 
-if __name__ == '__main__':
+def dev_tests():
 
     # from pylab import *
 
@@ -1671,3 +1711,7 @@ if __name__ == '__main__':
     print( C.get_Throat_Transport( Pc=100.0, MR=1.0, eps=40.0, frozen=1) )
     print( C.get_Exit_Transport( Pc=100.0, MR=1.0, eps=40.0, frozen=0) )
     print( C.get_Exit_Transport( Pc=100.0, MR=1.0, eps=40.0, frozen=1) )
+
+if __name__ == "__main__":
+    dev_tests()
+
