@@ -1,4 +1,3 @@
-from __future__ import print_function
 #!/usr/bin/env python
 # -*- coding: ascii -*-
 
@@ -168,6 +167,10 @@ class CEA_Obj( object ):
     def get_Throat_PcOvPe(self, Pc=100.0, MR=1.0):
         Pc = self.Pc_U.uval_to_dval( Pc ) # convert user units to psia
         return self.cea_obj.get_Throat_PcOvPe( Pc=Pc, MR=MR )
+    
+    def get_Pinj_over_Pcomb(self, Pc=100.0, MR=1.0, fac_CR=None):
+        Pc = self.Pc_U.uval_to_dval( Pc ) # convert user units to psia
+        return self.cea_obj.get_Pinj_over_Pcomb(Pc=Pc, MR=MR, fac_CR=fac_CR)
         
     def get_MachNumber(self, Pc=100.0, MR=1.0,eps=40.0, frozen=0, frozenAtThroat=0):
         Pc = self.Pc_U.uval_to_dval( Pc ) # convert user units to psia
@@ -375,7 +378,7 @@ class CEA_Obj( object ):
         
         return Cp, visc, cond, Prandtl
 
-if __name__ == "__main__":
+def dev_tests():
     
     C = CEA_Obj(oxName='N2O4', fuelName="MMH",
         isp_units='sec', cstar_units='ft/sec',
@@ -522,4 +525,8 @@ if __name__ == "__main__":
     print( C.get_Throat_Transport( Pc=100.0, MR=1.0, eps=40.0, frozen=1) )
     print( C.get_Exit_Transport( Pc=100.0, MR=1.0, eps=40.0, frozen=0) )
     print( C.get_Exit_Transport( Pc=100.0, MR=1.0, eps=40.0, frozen=1) )
+
+if __name__ == "__main__":
+    dev_tests()
+
     
\ No newline at end of file
